@@ -8,9 +8,9 @@
 #ifndef basictab_h
 #define basictab_h
 
+#include <KPageWidget>
 #include <KService>
 #include <QKeySequence>
-#include <QTabWidget>
 
 class KKeySequenceWidget;
 class QLineEdit;
@@ -24,7 +24,7 @@ class KLineSpellChecking;
 class MenuFolderInfo;
 class MenuEntryInfo;
 
-class BasicTab : public QTabWidget
+class BasicTab : public KPageWidget
 {
     Q_OBJECT
 
@@ -86,10 +86,12 @@ protected:
     QCheckBox *_launchCB = nullptr;
     QCheckBox *_onlyShowInKdeCB = nullptr;
     QCheckBox *_hiddenEntryCB = nullptr;
+    QCheckBox *_gpuCB = nullptr;
     KIconButton *_iconButton = nullptr;
     QGroupBox *_workPathGroup = nullptr;
     QGroupBox *_terminalGroup = nullptr;
     QGroupBox *_userGroup = nullptr;
+    QGroupBox *_gpuGroup = nullptr;
     QGroupBox *_keyBindingGroup = nullptr;
     QLabel *_terminalOptionsLabel = nullptr;
     QLabel *_userNameLabel = nullptr;
